<?php

use Drupal\Core\Url;

/**
 * Return current date.
 */
function function_filter__current_date($format = 'r') {
  return date($format);
}

/**
 * Return contact form.
 */
function function_filter__contact_form($contact_form_id) {
  $contact_message = \Drupal::entityTypeManager()
    ->getStorage('contact_message')
    ->create(['contact_form' => $contact_form_id]);

  $form = \Drupal::service('entity.form_builder')->getForm($contact_message);
  $form['#cache']['contexts'][] = 'user.permissions';

  return $form;
}

/**
 * Return views.
 */
function function_filter__views($view_id, $display_name = 'default') {
  return views_embed_view($view_id, $display_name);
}

/**
 * Return menu.
 */
function function_filter__menu($menu_name, $root = NULL, $add_cache_context_by_active_trail = TRUE) {
  $menu_tree_builder = \Drupal::menuTree();

  $menu_tree_parameters = $menu_tree_builder->getCurrentRouteMenuTreeParameters($menu_name);
  $menu_tree_parameters->setMinDepth(1);

  if ($root) {
    $menu_tree_parameters->setRoot($root)->excludeRoot();
  }

  $menu_tree = $menu_tree_builder->load($menu_name, $menu_tree_parameters);
  $menu_tree = $menu_tree_builder->transform($menu_tree, [
    ['callable' => 'menu.default_tree_manipulators:checkAccess'],
    ['callable' => 'menu.default_tree_manipulators:generateIndexAndSort'],
  ]);

  $menu_tree_build = $menu_tree_builder->build($menu_tree);

  if ($add_cache_context_by_active_trail) {
    $menu_tree_build['#cache']['contexts'][] = 'route.menu_active_trails:' . $menu_name;
  }

  return $menu_tree_build;
}

/**
 * Return site mail.
 */
function function_filter__site_mail() {
  return \Drupal::config('system.site')->get('mail');
}

/**
 * Return site url.
 */
function function_filter__site_url($absolute = FALSE) {
  $url_options['absolute'] = $absolute;
  return Url::fromRoute('<front>', [], $url_options)->toString();
}
